@@ -1,3 +1,4 @@
+import json
 import os
 
 import pytest
@@ -45,7 +46,7 @@ def test_default(hatch, helpers, temp_dir, config_file):
     )
 
 
-def test_default_as_json(hatch, helpers, temp_dir, config_file):
+def test_default_as_json(hatch, temp_dir, config_file):
     config_file.model.template.plugins['default']['tests'] = False
     config_file.save()
 
@@ -64,11 +65,20 @@ def test_default_as_json(hatch, helpers, temp_dir, config_file):
         result = hatch('env', 'show', '--json')
 
     assert result.exit_code == 0, result.output
-    assert helpers.remove_trailing_spaces(result.output) == helpers.dedent(
-        """
-        {"default":{"type":"virtual"}}
-        """
-    )
+
+    environments = json.loads(result.output)
+    assert list(environments) == [
+        'default',
+        'hatch-build',
+        'hatch-static-analysis',
+        'hatch-test.py3.12',
+        'hatch-test.py3.11',
+        'hatch-test.py3.10',
+        'hatch-test.py3.9',
+        'hatch-test.py3.8',
+        'hatch-uv',
+    ]
+    assert environments['default'] == {'type': 'virtual'}
 
 
 def test_single_only(hatch, helpers, temp_dir, config_file):
