@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import json
 import os
 import shutil
@@ -6,7 +8,7 @@ import sys
 import time
 from contextlib import suppress
 from functools import lru_cache
-from typing import Generator, NamedTuple
+from typing import TYPE_CHECKING, Generator, NamedTuple
 
 import pytest
 from click.testing import CliRunner as __CliRunner
@@ -15,6 +17,7 @@ from platformdirs import user_cache_dir, user_data_dir
 
 from hatch.config.constants import AppEnvVars, ConfigEnvVars, PublishEnvVars
 from hatch.config.user import ConfigFile
+from hatch.env.utils import get_env_var
 from hatch.utils.ci import running_in_ci
 from hatch.utils.fs import Path, temp_directory
 from hatch.utils.platform import Platform
@@ -24,6 +27,9 @@ from hatchling.cli import hatchling
 
 from .helpers.templates.licenses import MIT, Apache_2_0
 
+if TYPE_CHECKING:
+    from unittest.mock import MagicMock
+
 PLATFORM = Platform()
 
 
@@ -65,7 +71,7 @@ def helpers():
 
 
 @pytest.fixture(scope='session', autouse=True)
-def isolation() -> Generator[Path, None, None]:
+def isolation(uv_on_path) -> Generator[Path, None, None]:
     with temp_directory() as d:
         data_dir = d / 'data'
         data_dir.mkdir()
@@ -83,6 +89,7 @@ def isolation() -> Generator[Path, None, None]:
             ConfigEnvVars.CACHE: str(cache_dir),
             PublishEnvVars.REPO: 'dev',
             'HATCH_SELF_TESTING': 'true',
+            get_env_var(plugin_name='virtual', option='uv_path'): uv_on_path,
             'PYAPP_COMMAND_NAME': os.urandom(4).hex(),
             'GIT_AUTHOR_NAME': 'Foo Bar',
             'GIT_AUTHOR_EMAIL': 'foo@bar.baz',
@@ -194,6 +201,11 @@ def python_on_path():
     return Path(sys.executable).stem
 
 
+@pytest.fixture(scope='session', autouse=True)
+def uv_on_path():
+    return shutil.which('uv')
+
+
 @pytest.fixture(scope='session')
 def compatible_python_distributions():
     from hatch.python.resolve import get_compatible_distributions
@@ -290,6 +302,28 @@ def devpi(tmp_path_factory, worker_id):
                 shutil.rmtree(devpi_data)
 
 
+@pytest.fixture
+def env_run(mocker) -> Generator[MagicMock, None, None]:
+    run = mocker.patch('subprocess.run', return_value=subprocess.CompletedProcess([], 0, stdout=b''))
+    mocker.patch('hatch.env.virtual.VirtualEnvironment.exists', return_value=True)
+    mocker.patch('hatch.env.virtual.VirtualEnvironment.dependency_hash', return_value='')
+    mocker.patch('hatch.env.virtual.VirtualEnvironment.command_context')
+    return run
+
+
+def is_hatchling_command(command) -> bool:
+    if not isinstance(command, list):
+        return False
+
+    if command[0] != 'python':
+        return False
+
+    if '-m' not in command:
+        return False
+
+    return command[command.index('-m') + 1] == 'hatchling'
+
+
 @pytest.fixture
 def mock_backend_process(request, mocker):
     if 'allow_backend_process' in request.keywords:
@@ -298,7 +332,7 @@ def mock_backend_process(request, mocker):
 
     def mock_process_api(api):
         def mock_process(command, **kwargs):
-            if not isinstance(command, list) or command[1:4] != ['-u', '-m', 'hatchling']:  # no cov
+            if not is_hatchling_command(command):  # no cov
                 return api(command, **kwargs)
 
             original_args = sys.argv
@@ -336,7 +370,7 @@ def mock_backend_process_output(request, mocker):
 
     def mock_process_api(api):
         def mock_process(command, **kwargs):
-            if not isinstance(command, list) or command[1:4] != ['-u', '-m', 'hatchling']:  # no cov
+            if not is_hatchling_command(command):  # no cov
                 return api(command, **kwargs)
 
             output_queue.clear()
@@ -354,7 +388,7 @@ def mock_backend_process_output(request, mocker):
                 else:
                     mock.returncode = 0
 
-                mock.stdout = ''.join(output_queue).encode('utf-8')
+                mock.stdout = mock.stderr = ''.join(output_queue).encode('utf-8')
                 return mock
             finally:
                 sys.argv = original_args
@@ -362,7 +396,7 @@ def mock_backend_process_output(request, mocker):
         return mock_process
 
     mocker.patch('subprocess.run', side_effect=mock_process_api(subprocess.run))
-    mocker.patch('hatchling.bridge.app._display', side_effect=lambda cmd: output_queue.append(f'{cmd}\n'))
+    mocker.patch('hatchling.bridge.app._display', side_effect=lambda cmd, **_: output_queue.append(f'{cmd}\n'))
 
     yield True
 
@@ -424,7 +458,7 @@ def pytest_runtest_setup(item):
         if marker.name == 'requires_unix' and PLATFORM.windows:
             pytest.skip('Not running on a Linux-based platform')
 
-        if marker.name == 'requires_git' and not shutil.which('git'):
+        if marker.name == 'requires_git' and not shutil.which('git'):  # no cov
             pytest.skip('Git not present in the environment')
 
 
